@@ -1,4 +1,4 @@
-<?
+<?php
    /* ldapquery plugin version 1.4
     *
     * Undoubtedly there are better/faster ways to do what I do here,
@@ -54,6 +54,7 @@
    function ldapquery_dispresultsMulti ($attributes, $entry, $sortby) {
       // sort the entries. First, build an array with the sortby as the key
       // and the entry index as the value
+      global $compose_new_win, $base_uri;
       if ($entry["count"] > 0) {
          for ($i=0 ; $i < $entry["count"]; $i++) {
             $Val = $entry[$i][$sortby][0] . $i;
@@ -101,8 +102,14 @@
                         break;
                      case "mail":
                         $val = $entry[$i][$attr][$x];
-                        displayInternalLink ("src/compose.php?send_to=$val",
-                                             "$val", "right");
+			if ($compose_new_win == '1') {
+			    print ("<a href=$base_uri/src/compose.php".
+			           "?send_to=$val target=\"compose_window\" ".
+				   "onClick=\"comp_in_new()\">$val</a>\n");
+			} else {
+                            displayInternalLink ("src/compose.php?send_to=$val",
+                                                 "$val", "right");
+			}
                         break;
                      default:
                         $val = $entry[$i][$attr][$x] . "$<END>";
